@@ -264,9 +264,9 @@ extract_fit.coxme = function(.data, explanatory_name="explanatory", estimate_nam
 	results = extract_coxme_table(.data)
 	explanatory = row.names(results)
 	estimate = exp(results$beta)
-	confint_results = confint(.data, level = confint_level) %>% exp()
-	confint_L = confint_results[, 1]
-	confint_U = confint_results[, 2]
+	confint_results = confint(.data, level = confint_level)
+	confint_L = exp(confint_results[, 1])
+	confint_U = exp(confint_results[, 2])
 	p = results$p
 	df.out = dplyr::tibble(explanatory, estimate, confint_L, confint_U, p)
 	colnames(df.out) = c(explanatory_name, paste0(estimate_name, estimate_suffix), "L95", "U95", p_name)
@@ -424,12 +424,17 @@ p_tidy = function(x, digits, prefix="="){
 #' @param n Value
 #' @param percent Value
 #' @param digits Value
+#' @param na_include When proportion missing, include in parentheses?
 #'
 #' @export
 #'
-format_n_percent = function(n, percent, digits) {
+format_n_percent = function(n, percent, digits, na_include = TRUE) {
 	percent = round_tidy(percent, digits)
-	paste0(n, " (", percent, ")")
+	out = paste0(n, " (", percent, ")")
+	if(!na_include){
+		out = gsub(" \\(NA\\)", "", out)
+	}
+	return(out)
 }
 
 #' Remove intercept from model output
